@@ -2,7 +2,7 @@
 
 
 package Device::Hypnocube;
-$Device::Hypnocube::VERSION = '1.9.2';
+$Device::Hypnocube::VERSION = '1.9.3';
 use 5.010;
 use strict;
 use warnings;
@@ -631,12 +631,25 @@ sub get_color {
         my $r = int( rand( scalar(@color_names) ) );
         ( $color, $green, $blue ) = @{ $colors{ $color_names[$r] } };
     }
+    # alias for black
+    if ( $color =~ /^(clear|off)$/i ) {
+        ( $color, $green, $blue ) = (0, 0, 0);
+    }
+
+    my $tc = colorname_to_hex( $color) ;
+    $color = "#$tc" if( $tc) ;
 
     if ( $color =~ /^(?:0[xX]|#)([[:xdigit:]]+)$/ && !defined $green && !defined $blue ) {
         my $c = $1;
         if ( length($c) == 2 ) {
             $color = $green = $blue = hex($c);
         }
+        elsif ( length($c) == 3 ) {
+            $c =~ /([[:xdigit:]])([[:xdigit:]])([[:xdigit:]])/;
+            $color = hex("$1$1");
+            $green = hex("$2$2");
+            $blue  = hex("$3$3");
+        }
         elsif ( length($c) == 6 ) {
             $c =~ /([[:xdigit:]]{2})([[:xdigit:]]{2})([[:xdigit:]]{2})/;
             $color = hex($1);
@@ -871,7 +884,7 @@ Device::Hypnocube - Control a hypnocube
 
 =head1 VERSION
 
-version 1.9.2
+version 1.9.3
 
 =head1 SYNOPSIS
 
